@@ -8,14 +8,14 @@ from .utils import *
 class MetaClass(type):
     def __new__(cls, name, bases, attr):
         # Replace each function with type checked one
-        for name, value in attr.items():
-            if not name.startswith("_"):
+        for key, value in attr.items():
+            if not key.startswith("_"):
                 if type(value) is FunctionType or type(value) is MethodType:
-                    attr[name] = my_beartype(value)
+                    attr[key] = my_beartype(value)
                 elif isinstance(value, classmethod):
-                    attr[name] = classmethod(my_beartype(value.__func__))
+                    attr[key] = classmethod(my_beartype(value.__func__))
                 elif isinstance(value, staticmethod):
-                    attr[name] = staticmethod(my_beartype(value.__func__))
+                    attr[key] = staticmethod(my_beartype(value.__func__))
                 # elif isinstance(value, property):
 
         return super(MetaClass, cls).__new__(cls, name, bases, attr)
